%% setup.m
% UAV Software-in-the-Loop Simulation setup
%
% This script will setup the SIL simulation. Stored aircraf configuration
% and trim conditions are used.
%
% University of Minnesota 
% Aerospace Engineering and Mechanics 
% Copyright 2011 Regents of the University of Minnesota. 
% All rights reserved.
%
% SVN Info: $Id: setup.m 284 2011-03-03 15:07:19Z murch $

%% Clean up
clear all
close all
bdclose all
clc

%% Add Libraries folder to MATLAB path
addpath ../Libraries

%% Load airframe configuration and trim condition
% To change these, use the functions "UAV_config.m" and "trim_UAV.m"
load UAV_modelconfig
load UAV_trimcondition

%% Set controller variants and mode
% Each variant corresponds to a different controller block that will be
% referenced in UAV_SIL/Control Law/Control Software. You can define
% additional variants, say if you wanted to test multiple control laws.
flightcode_var = Simulink.Variant('controller_mode == 1');
simulink_controller_var = Simulink.Variant('controller_mode == 2');

% Set controller mode: 1 = flight code (C) controller, 2 = simulink controller
controller_mode = 1; 

%% Compile Flight Software if selected
% control_code_path contains the location and name of the controller which
% implements the control_law_interface.h functions. Change it according to
% the desired controller.
if controller_mode == 1
    control_code_path = '../../Software/FlightCode/control/lqr_control.c';
    %control_code_path = '../../Software/FlightCode/control/baseline_control.c';
    
    eval(['mex -g -DSIL_MODE_  -I../../Software/FlightCode/control/ control_manager_SIL.c ' control_code_path]);
end

%% Set control law sample times
% Sample time of flight software
SW_SampleTime = 0.04; % sec

% Time delay in flight software loop
TimeDelay = 0.04; % sec

%% Simulation sample time
SampleTime = 0.02; % sec

%% Open sim diagram
UAV_SIL
